@@ -26,6 +26,7 @@
 
 #include <rpc_common.h>
 #include <ndr.h>
+#include <gen_ndr/security.h>
 
 /* modules can use the following to determine if the interface has changed
  * please increment the version number after each interface change
@@ -115,7 +116,7 @@ struct dcesrv_call_state {
 	 * and skip the reply
 	 *
 	 * this is only allowed to the backend when DCESRV_CALL_STATE_FLAG_MAY_ASYNC
-	 * is alerady set by the frontend
+	 * is already set by the frontend
 	 *
 	 * the backend then needs to call dcesrv_reply() when it's
 	 * ready to send the reply
@@ -191,7 +192,7 @@ struct dcesrv_handle {
 	struct dcesrv_handle *next, *prev;
 	struct dcesrv_assoc_group *assoc_group;
 	struct policy_handle wire_handle;
-	struct dom_sid *sid;
+	struct dom_sid sid;
 	enum dcerpc_AuthLevel min_auth_level;
 	const struct dcesrv_interface *iface;
 	void *data;
@@ -380,15 +381,22 @@ struct dcesrv_assoc_group {
 
 struct dcesrv_context_callbacks {
 	struct {
-		void (*successful_authz)(struct dcesrv_call_state *);
+		void (*successful_authz)(
+			struct dcesrv_call_state *call, void *private_data);
+		void *private_data;
 	} log;
 	struct {
-		NTSTATUS (*gensec_prepare)(TALLOC_CTX *mem_ctx,
-					struct dcesrv_call_state *call,
-					struct gensec_security **out);
+		NTSTATUS (*gensec_prepare)(
+			TALLOC_CTX *mem_ctx,
+			struct dcesrv_call_state *call,
+			struct gensec_security **out,
+			void *private_data);
+		void *private_data;
 	} auth;
 	struct {
-		NTSTATUS (*find)(struct dcesrv_call_state *);
+		NTSTATUS (*find)(
+			struct dcesrv_call_state *call, void *private_data);
+		void *private_data;
 	} assoc_group;
 };
 
@@ -432,7 +440,7 @@ struct dcesrv_context {
 
 	struct dcesrv_connection *broken_connections;
 
-	struct dcesrv_context_callbacks callbacks;
+	struct dcesrv_context_callbacks *callbacks;
 };
 
 /* this structure is used by modules to determine the size of some critical types */
@@ -626,9 +634,9 @@ _PUBLIC_ NTSTATUS dcesrv_connection_loop_start(struct dcesrv_connection *conn);
 
 _PUBLIC_ NTSTATUS dcesrv_call_dispatch_local(struct dcesrv_call_state *call);
 
-_PUBLIC_ const struct dcesrv_interface *find_interface_by_uuid(
-				const struct dcesrv_endpoint *endpoint,
-				const struct GUID *uuid, uint32_t if_version);
+_PUBLIC_ const struct dcesrv_interface *find_interface_by_syntax_id(
+	const struct dcesrv_endpoint *endpoint,
+	const struct ndr_syntax_id *interface);
 
 void _dcesrv_save_ndr_fuzz_seed(DATA_BLOB call_blob,
 				struct dcesrv_call_state *call,
